Struct google_pubsub1::api::AcknowledgeRequest [−][src]
Request for the Acknowledge method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- subscriptions acknowledge projects (request)
Fields
ack_ids: Option<Vec<String>>Required. The acknowledgment ID for the messages being acknowledged that was returned by the Pub/Sub system in the Pull response. Must not be empty.