Struct google_pubsub1::api::CreateSnapshotRequest [−][src]
Request for the CreateSnapshot method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- snapshots create projects (request)
Fields
labels: Option<HashMap<String, String>>See Creating and managing labels.
subscription: Option<String>Required. The subscription whose backlog the snapshot retains. Specifically, the created snapshot is guaranteed to retain: (a) The existing backlog on the subscription. More precisely, this is defined as the messages in the subscription’s backlog that are unacknowledged upon the successful completion of the CreateSnapshot request; as well as: (b) Any messages published to the subscription’s topic following the successful completion of the CreateSnapshot request. Format is projects/{project}/subscriptions/{sub}.