Struct google_pubsub1::api::ExpirationPolicy [−][src]
A policy that specifies the conditions for resource expiration (i.e., automatic resource deletion).
This type is not used in any activity, and only used as part of another schema.
Fields
ttl: Option<String>Specifies the “time-to-live” duration for an associated resource. The resource expires if it is not active for a period of ttl. The definition of “activity” depends on the type of the associated resource. The minimum and maximum allowed values for ttl depend on the type of the associated resource, as well. If ttl is not set, the associated resource never expires.