pub struct IngestionDataSourceSettings {
pub aws_kinesis: Option<AwsKinesis>,
pub aws_msk: Option<AwsMsk>,
pub azure_event_hubs: Option<AzureEventHubs>,
pub cloud_storage: Option<CloudStorage>,
pub confluent_cloud: Option<ConfluentCloud>,
pub platform_logs_settings: Option<PlatformLogsSettings>,
}Expand description
Settings for an ingestion data source on a topic.
This type is not used in any activity, and only used as part of another schema.
Fields
aws_kinesis: Option<AwsKinesis>Optional. Amazon Kinesis Data Streams.
aws_msk: Option<AwsMsk>Optional. Amazon MSK.
azure_event_hubs: Option<AzureEventHubs>Optional. Azure Event Hubs.
cloud_storage: Option<CloudStorage>Optional. Cloud Storage.
confluent_cloud: Option<ConfluentCloud>Optional. Confluent Cloud.
platform_logs_settings: Option<PlatformLogsSettings>Optional. Platform Logs settings. If unset, no Platform Logs will be generated.