pub struct ModifyAckDeadlineRequest {
pub ack_deadline_seconds: Option<i32>,
pub ack_ids: Option<Vec<String>>,
}Expand description
Request for the ModifyAckDeadline method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
ack_deadline_seconds: Option<i32>Required. The new ack deadline with respect to the time this request was sent to the Pub/Sub system. For example, if the value is 10, the new ack deadline will expire 10 seconds after the ModifyAckDeadline call was made. Specifying zero might immediately make the message available for delivery to another subscriber client. This typically results in an increase in the rate of message redeliveries (that is, duplicates). The minimum deadline you can specify is 0 seconds. The maximum deadline you can specify in a single request is 600 seconds (10 minutes).
ack_ids: Option<Vec<String>>Required. List of acknowledgment IDs.