pub struct PubSubAvroFormat { /* private fields */ }Expand description
Configuration for reading Cloud Storage data written via Cloud Storage subscriptions. The data and attributes fields of the originally exported Pub/Sub message will be restored when publishing.
This type is not used in any activity, and only used as part of another schema.