Struct google_pubsub1::api::PullRequest[][src]

pub struct PullRequest {
    pub max_messages: Option<i32>,
    pub return_immediately: Option<bool>,
}

Request for the Pull method.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

max_messages: Option<i32>

Required. The maximum number of messages to return for this request. Must be a positive integer. The Pub/Sub system may return fewer than the number specified.

return_immediately: Option<bool>

Optional. If this field set to true, the system will respond immediately even if it there are no messages available to return in the Pull response. Otherwise, the system may wait (for a bounded amount of time) until at least one message is available, rather than returning no messages. Warning: setting this field to true is discouraged because it adversely impacts the performance of Pull operations. We recommend that users do not set this field.