Struct google_pubsub1::api::Schema[][src]

pub struct Schema {
    pub definition: Option<String>,
    pub name: Option<String>,
    pub type_: Option<String>,
}

A schema resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

definition: Option<String>

The definition of the schema. This should contain a string representing the full definition of the schema that is a valid schema definition of the type specified in type.

name: Option<String>

Required. Name of the schema. Format is projects/{project}/schemas/{schema}.

type_: Option<String>

The type of the schema definition.