Struct google_pubsub1::api::SchemaSettings[][src]

pub struct SchemaSettings {
    pub encoding: Option<String>,
    pub schema: Option<String>,
}

Settings for validating messages published against a schema.

This type is not used in any activity, and only used as part of another schema.

Fields

encoding: Option<String>

The encoding of messages validated against schema.

schema: Option<String>

Required. The name of the schema that messages published should be validated against. Format is projects/{project}/schemas/{schema}. The value of this field will be _deleted-schema_ if the schema has been deleted.