Struct google_pubsub1::api::UpdateTopicRequest [−][src]
Request for the UpdateTopic method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- topics patch projects (request)
Fields
topic: Option<Topic>Required. The updated topic object.
update_mask: Option<String>Required. Indicates which fields in the provided topic to update. Must be specified and non-empty. Note that if update_mask contains “message_storage_policy” but the message_storage_policy is not set in the topic provided above, then the updated value is determined by the policy configured at the project or organization level.