Struct google_pubsub1::api::ValidateSchemaRequest[][src]

pub struct ValidateSchemaRequest {
    pub schema: Option<Schema>,
}

Request for the ValidateSchema method.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

schema: Option<Schema>

Required. The schema object to validate.