pub struct ListTopicSubscriptionsResponse {
pub next_page_token: Option<String>,
pub subscriptions: Option<Vec<String>>,
}Expand description
Response for the ListTopicSubscriptions method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- topics subscriptions list projects (response)
Fields
next_page_token: Option<String>If not empty, indicates that there may be more subscriptions that match
the request; this value should be passed in a new
ListTopicSubscriptionsRequest to get more subscriptions.
subscriptions: Option<Vec<String>>The names of the subscriptions that match the request.