Struct google_pubsub1::ModifyPushConfigRequest [−][src]
pub struct ModifyPushConfigRequest {
pub push_config: Option<PushConfig>,
}Request for the ModifyPushConfig method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
push_config: Option<PushConfig>
The push configuration for future deliveries.
An empty pushConfig indicates that the Pub/Sub system should
stop pushing messages from the given subscription and allow
messages to be pulled and acknowledged - effectively pausing
the subscription if Pull or StreamingPull is not called.