Struct google_pubsub1::UpdateSubscriptionRequest[][src]

pub struct UpdateSubscriptionRequest {
    pub update_mask: Option<String>,
    pub subscription: Option<Subscription>,
}

Request for the UpdateSubscription method.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

Indicates which fields in the provided subscription to update. Must be specified and non-empty.

The updated subscription object.