pub struct SchemaSettings {
pub encoding: Option<String>,
pub first_revision_id: Option<String>,
pub last_revision_id: Option<String>,
pub schema: Option<String>,
}Expand description
Settings for validating messages published against a schema.
This type is not used in any activity, and only used as part of another schema.
Fields
encoding: Option<String>Optional. The encoding of messages validated against schema.
first_revision_id: Option<String>Optional. The minimum (inclusive) revision allowed for validating messages. If empty or not present, allow any revision to be validated against last_revision or any revision created before.
last_revision_id: Option<String>Optional. The maximum (inclusive) revision allowed for validating messages. If empty or not present, allow any revision to be validated against first_revision or any revision created after.
schema: Option<String>Required. The name of the schema that messages published should be validated against. Format is projects/{project}/schemas/{schema}. The value of this field will be _deleted-schema_ if the schema has been deleted.