pub struct SeekRequest {
pub snapshot: Option<String>,
pub time: Option<DateTime<Utc>>,
}Expand description
Request for the Seek method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- subscriptions seek projects (request)
Fields
snapshot: Option<String>Optional. The snapshot to seek to. The snapshot’s topic must be the same as that of the provided subscription. Format is projects/{project}/snapshots/{snap}.
time: Option<DateTime<Utc>>Optional. The time to seek to. Messages retained in the subscription that were published before this time are marked as acknowledged, and messages retained in the subscription that were published after this time are marked as unacknowledged. Note that this operation affects only those messages retained in the subscription (configured by the combination of message_retention_duration and retain_acked_messages). For example, if time corresponds to a point before the message retention window (or to a point before the system’s notion of the subscription creation time), only retained messages will be marked as unacknowledged, and already-expunged messages will not be restored.