Snapshot

Struct Snapshot 

pub struct Snapshot {
    pub expire_time: Option<DateTime<Utc>>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub topic: Option<String>,
}
A snapshot resource. Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

expire_time: Option<DateTime<Utc>>

Optional. The snapshot is guaranteed to exist up until this time. A newly-created snapshot expires no later than 7 days from the time of its creation. Its exact lifetime is determined at creation by the existing backlog in the source subscription. Specifically, the lifetime of the snapshot is 7 days - (age of oldest unacked message in the subscription). For example, consider a subscription whose oldest unacked message is 3 days old. If a snapshot is created from this subscription, the snapshot – which will always capture this 3-day-old backlog as long as the snapshot exists – will expire in 4 days. The service will refuse to create a snapshot that would expire in less than 1 hour after creation.

labels: Option<HashMap<String, String>>

Optional. See [Creating and managing labels] (https://cloud.google.com/pubsub/docs/labels).

name: Option<String>

Optional. The name of the snapshot.

topic: Option<String>

Optional. The name of the topic from which this snapshot is retaining messages.