Struct google_pubsub1::api::UpdateSnapshotRequest [−][src]
Request for the UpdateSnapshot method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- snapshots patch projects (request)
Fields
snapshot: Option<Snapshot>Required. The updated snapshot object.
update_mask: Option<String>Required. Indicates which fields in the provided snapshot to update. Must be specified and non-empty.