Struct google_pubsub1::api::UpdateSubscriptionRequest [−][src]
Request for the UpdateSubscription method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- subscriptions patch projects (request)
Fields
subscription: Option<Subscription>Required. The updated subscription object.
update_mask: Option<String>Required. Indicates which fields in the provided subscription to update. Must be specified and non-empty.