Struct google_pubsub1::api::ValidateMessageRequest [−][src]
Request for the ValidateMessage method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- schemas validate message projects (request)
Fields
encoding: Option<String>The encoding expected for messages
message: Option<String>Message to validate against the provided schema_spec.
name: Option<String>Name of the schema against which to validate. Format is projects/{project}/schemas/{schema}.
schema: Option<Schema>Ad-hoc schema against which to validate